Attribute VB_Name = "ExplCoreProcedures"
' -------------------------------------------------------------------------
' Filename:     ExplCore.Bas
' Project:      Generic Explorer
'
' Purpose:      This is ...
'
' -------------------------------------------------------------------------
' Revisions
'
' -------------------------------------------------------------------------
Option Explicit

Dim gbTest As Boolean

' Definition of keys used in tree view and list view
' --------------------------------------------------
'
' Entries in views are one of the following five types
' "Root": the root (absolute beginning) of the tree view
'    (one and only one, always visible)
' "TreeFamily": next level from the root, may have trunks, branches, or leaves
'    (only one entry in the view of each family, one or more family types)
' "Trunk": may have branches or leaves (some family types don't have trunks)
'    (zero or more, similar types within a "family")
' "Branch": may have branches or leaves (some family types don't have branches)
'    (zero or more, similar types within a "trunk")
' "Leaf": terminating type within the structure,
'    leaves cannot have descendants
'
' =======================================================
' may be shown                      may be shown
' in TreeView                       in ListView       Key
'       Y       "Root"                    N           "R"
'       Y       +-- "TreeFamily"          Y           "F"
'       Y           +-- "Trunk"           Y           "T"
'       Y               +-- "Branch"      Y           "B"
'       N                   +-- "Leaf"    Y           "L"
' =======================================================
' Example with all types of entry
'               "Computer"
'               +-- "Disk Drives"
'                   +-- "Drive"
'                       +-- "Directory"
'                           +-- "Files"
' =======================================================
' Example that doesn't have trunks or branches:
'               "Computer"
'               +-- "Control Panel"
'                           +-- "Control Panel Applets"
' =======================================================

' Tag(3), Lvl(1),    Type(1),   Index(3)(???), Name(rest)
' xxx     R,F,T,B,L  A,B,C,...  000,BMP,etc


Public Const gsNODE_PROXY As String = "....."

Public Const giIMG_FOLDERCLOSED = 1
Public Const giIMG_FOLDEROPEN = 2
Public Const giIMG_FLOPPY514 = 3
Public Const giIMG_FLOPPY35 = 4
Public Const giIMG_HARDDRIVE = 5
Public Const giIMG_NETDRIVE = 6
Public Const giIMG_CDROMDRIVE = 7
Public Const giIMG_MYCOMPUTER = 8
Public Const giIMG_GLOBE = 9
Public Const giIMG_DESKTOP = 10
Public Const giIMG_RAMDRIVE = 11
Public Const giIMG_FILE = 12
Public Const giIMG_SHORTCUTCLOSED = 13
Public Const giIMG_SHORTCUTOPEN = 14
Public Const giIMG_SHORTCUTFILE = 15


Public Const giKEY_TAG_POS = 1
Public Const giKEY_TAG_LEN = 3
Public Const giKEY_LVL_POS = 4
Public Const giKEY_LVL_LEN = 1
Public Const giKEY_TYPE_POS = 5
Public Const giKEY_TYPE_LEN = 1
Public Const giKEY_IDX_POS = 6
Public Const giKEY_IDX_LEN = 3
Public Const giKEY_NAME_POS = 9

Public Const gsKEYIDX_ZERO = "000"
Public Const gsKEYLVL_ROOT = "R"
Public Const gsKEYLVL_FAMILY = "F"
Public Const gsKEYLVL_TREE = "T"
Public Const gsKEYLVL_BRANCH = "B"
Public Const gsKEYLVL_LEAF = "L"

'- API Declarations -------------------------------
Declare Function BringWindowToTop Lib "user32" (ByVal hwnd As Long) As Long
Declare Function DrawIcon Lib "user32" (ByVal hdc As Long, ByVal x As Long, ByVal y As Long, ByVal hIcon As Long) As Long
Declare Function DrawIconEx Lib "user32" (ByVal hdc As Long, ByVal xLeft As Long, ByVal yTop As Long, ByVal hIcon As Long, ByVal cxWidth As Long, ByVal cyWidth As Long, ByVal istepIfAniCur As Long, ByVal hbrFlickerFreeDraw As Long, ByVal diFlags As Long) As Boolean
Declare Function ExtractAssociatedIcon Lib "shell32.dll" Alias "ExtractAssociateIconA" (ByVal hInst As Long, ByVal lpIconPath As String, lpiIcon As Long) As Long
Declare Function ExtractIcon Lib "shell32.dll" Alias "ExtractIconA" (ByVal hInst As Long, ByVal lpszExeFileName As String, ByVal nIconIndex As Long) As Long
Declare Function FindWindow Lib "user32" Alias "FindWindowA" (ByVal lpClassName As String, ByVal lpWindowName As String) As Long
Declare Function GetClassLong Lib "user32" Alias "GetClassLongA" (ByVal hwnd As Long, ByVal nIndex As Long) As Long
Declare Function GetDriveType Lib "kernel32" Alias "GetDriveTypeA" (ByVal sDrive As String) As Long
Declare Function GetLastError Lib "kernel32" () As Long
Declare Function GetModuleFileName Lib "kernel32" Alias "GetModuleFileNameA" (ByVal hModule As Long, ByVal lpFileName As String, ByVal nSize As Long) As Long
Declare Function GetTempPath Lib "kernel32" Alias "GetTempPathA" (ByVal nBufferLength As Long, ByVal lpBuffer As String) As Long
Declare Function GetWindowLong Lib "user32" Alias "GetWindowLongA" (ByVal hwnd As Long, ByVal nIndex As Long) As Long
Declare Function GetWindowText Lib "user32" Alias "GetWindowTextA" (ByVal hwnd As Long, ByVal lpString As String, ByVal cch As Long) As Long
Declare Function GetWindowTextLength Lib "user32" Alias "GetWindowTextLengthA" (ByVal hwnd As Long) As Long
Declare Function LoadIcon Lib "user32" Alias "LoadIconA" (ByVal hInstance As Long, ByVal lpIconName As Any) As Long
Declare Function SendMessage Lib "user32" Alias "SendMessageA" (ByVal hwnd As Long, ByVal wMsg As Long, ByVal wParam As Long, lParam As Any) As Long
Declare Function SetFocusAPI Lib "user32" Alias "SetFocus" (ByVal hwnd As Long) As Long
Declare Function SetForegroundWindow Lib "user32" (ByVal hwnd As Long) As Long
Declare Function SetWindowPos Lib "user32" (ByVal hwnd As Long, ByVal hWndInsertAfter As Long, ByVal x As Long, ByVal y As Long, ByVal cx As Long, ByVal cy As Long, ByVal wFlags As Long) As Long
Declare Function ShowWindow Lib "user32" (ByVal hwnd As Long, ByVal nCmdShow As Long) As Long

'- API Constants ------------------------------
Public Const DI_NORMAL = 3

Public Const SWP_NOMOVE = &H2
Public Const SWP_NOSIZE = &H1
Public Const SWP_SHOWWINDOW = &H40

Public Const HWND_TOP = 0
Public Const HWND_TOPMOST = -1
Public Const HWND_NOTOPMOST = -2

Public Const SW_RESTORE = 9
Public Const SW_NORMAL = 1
Public Const SW_SHOW = 5
Public Const SW_SHOWDEFAULT = 10
Public Const SW_SHOWNORMAL = 1
    
Public Const DRIVE_CDROM = 5
Public Const DRIVE_FIXED = 3
Public Const DRIVE_RAMDISK = 6
Public Const DRIVE_REMOTE = 4
Public Const DRIVE_REMOVABLE = 2

Public giInstanceID As Integer
Public gbLoadInitCompleted As Boolean
Public colFamily() As Collection


' -------------------------------------------------------------------------
'Purpose:   ?
'Inputs:    ?:   ?
'Assumes:   ?
'Effects:   ?
' -------------------------------------------------------------------------
Public Sub MenuPopupListItem(rLeft As Single, rTop As Single)
' -----------------------------------------------------------------
' -----------------------------------------------------------------
    frmMainExplorer.PopupMenu frmMainExplorer.mnuEdit, , rLeft, rTop
End Sub

' -------------------------------------------------------------------------
'Purpose:   ?
'Inputs:    ?:   ?
'Assumes:   ?
'Effects:   ?
' -------------------------------------------------------------------------
Public Sub MenuPopupListView(rLeft As Single, rTop As Single)
' -----------------------------------------------------------------
' -----------------------------------------------------------------
    frmMainExplorer.PopupMenu frmMainExplorer.mnuView, , rLeft, rTop
End Sub

' -------------------------------------------------------------------------
'Purpose:   ?
'Inputs:    ?:   ?
'Assumes:   ?
'Effects:   ?
' -------------------------------------------------------------------------
Public Sub MenuPopupTreeItem(rLeft As Single, rTop As Single)
' -----------------------------------------------------------------
' -----------------------------------------------------------------
    frmMainExplorer.PopupMenu frmMainExplorer.mnuEdit, , rLeft, rTop
End Sub

' -------------------------------------------------------------------------
'Purpose:   ?
'Inputs:    ?:   ?
'Assumes:   ?
'Effects:   ?
' -------------------------------------------------------------------------
Public Sub MenuPopupTreeView(rLeft As Single, rTop As Single)
' -----------------------------------------------------------------
' -----------------------------------------------------------------
    frmMainExplorer.PopupMenu frmMainExplorer.mnuView, , rLeft, rTop
End Sub
